package envoy.client.ui;

import java.awt.Dimension;
import java.text.SimpleDateFormat;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;

import envoy.client.data.Settings;
import envoy.client.ui.list.ComponentList;
import envoy.client.ui.list.ComponentListCellRenderer;
import envoy.data.Message;

/**
 * Defines how a message is displayed.<br>
 * <br>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>MessageListRenderer.java</strong><br>
 * Created: <strong>19 Oct 2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @author Maximilian K&auml;fer
 * @since Envoy v0.1-alpha
 */
public class MessageListRenderer implements ComponentListCellRenderer<Message> {

	@Override
	public JPanel getListCellComponent(ComponentList<? extends Message> list, Message value, boolean isSelected) {
		final JPanel	panel	= new JPanel();
		final Theme		theme	= Settings.getInstance().getThemes().get(Settings.getInstance().getCurrentTheme());

		// Panel background
		panel.setBackground(isSelected ? theme.getSelectionColor() : theme.getCellColor());

		// TODO: Handle message attachments

		final String	text	= value.getText();
		final String	state	= value.getStatus().toString();
		final String	date	= new SimpleDateFormat("dd.MM.yyyy HH.mm").format(value.getCreationDate());

		// Message text color
		String textColor = theme.getMessageColorChat().toHex();

		// Message date color
		String dateColor = theme.getDateColorChat().toHex();

		panel.add(new JLabel(String.format("<html><p style=\"color:%s\"><b><small>%s</b></small><br><p style=\"color:%s\">%s :%s</html>",
				dateColor,
				date,
				textColor,
				text,
				state)));

		// Define some space to the messages below
		panel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(), BorderFactory.createEtchedBorder()));

		// Set the width to the list width
		Dimension size = new Dimension(list.getWidth() - 25, panel.getPreferredSize().height);
		panel.setMaximumSize(size);
		panel.setMinimumSize(size);
		panel.setPreferredSize(size);

		return panel;
	}
}